==> zjkj-wzxt-impl-3.0.0-20240809.095726-58-sources.jar: com/ejianc/wzxt/delivery/service/impl/DeliveryServiceImpl.java <==
package com.ejianc.wzxt.delivery.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.weigh.weighbill.api.IPushThirdDataApi;
import com.ejianc.business.weigh.weighbill.vo.DeliveryDetailThirdVO;
import com.ejianc.business.weigh.weighbill.vo.DeliveryThirdVO;
import com.ejianc.foundation.share.api.IProSupplierApi;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.cache.utils.RedisTool;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ComputeUtil;
import com.ejianc.framework.skeleton.dataPush.ISystemDataPushService;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import com.ejianc.wzxt.check.vo.CheckDetailVO;
import com.ejianc.wzxt.check.vo.CheckVO;
import com.ejianc.wzxt.delivery.bean.DeliveryDetailEntity;
import com.ejianc.wzxt.delivery.bean.DeliveryEntity;
import com.ejianc.wzxt.delivery.mapper.DeliveryMapper;
import com.ejianc.wzxt.delivery.service.IDeliveryService;
import com.ejianc.wzxt.delivery.vo.DeliveryDetailVO;
import com.ejianc.wzxt.delivery.vo.DeliveryVO;
import com.ejianc.wzxt.enums.CheckTypeEnum;
import com.ejianc.wzxt.order.bean.OrderDetailEntity;
import com.ejianc.wzxt.order.bean.OrderEntity;
import com.ejianc.wzxt.order.service.IOrderService;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestMethod;
import redis.clients.jedis.Jedis;
import redis.clients.jedis.JedisPool;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * 消耗材-发货单
 *
 * @author generator
 */
@Service("deliveryService")
public class DeliveryServiceImpl extends BaseServiceImpl<DeliveryMapper, DeliveryEntity> implements IDeliveryService {
    @Autowired
    private IDeliveryService deliveryService;
    private final Logger logger = LoggerFactory.getLogger(getClass());
    private final String PUSH_BILL_SERVER_URL = "/zjkj-supbusiness-web/openapi/delivery/saveMaterialDeliveryState";
    @Autowired
    private JedisPool jedisPool;
    @Autowired
    private IProSupplierApi proSupplierApi;
    @Autowired
    private IPushThirdDataApi pushThirdDataApi;
    @Autowired
    private IOrderService orderService;
    @Autowired
    private ISystemDataPushService systemDataPushService;
    private static final String BILL_CODE = "ZJKJ-DELIVERY-CODE";//此处需要根据实际修改
    private final String OPERATE = "ZJKJ_DELIVERY_SYNC";
    private static final String BILL_TYPE_CODE = "EJCBT202407000005";//此处需要根据实际修改
    @Autowired
    private IBillCodeApi billCodeApi;

    @Override
    public CheckVO queryDetailToCheck(Long id) {
        DeliveryEntity deliveryEntity = deliveryService.selectById(id);

        //处理组合验收数据返回
        CheckVO checkVO = new CheckVO();
        checkVO.setOrderId(deliveryEntity.getOrderId());
        checkVO.setDeliveryId(deliveryEntity.getId());
        checkVO.setCheckState(0);
        checkVO.setContractId(deliveryEntity.getContractId());
        checkVO.setContractName(deliveryEntity.getContractName());
        checkVO.setContractCode(deliveryEntity.getContractCode());
        checkVO.setProjectCode(deliveryEntity.getProjectCode());
        checkVO.setProjectId(deliveryEntity.getProjectId());
        checkVO.setProjectName(deliveryEntity.getProjectName());
        checkVO.setSupplierId(deliveryEntity.getSupplierId());
        checkVO.setSupplierName(deliveryEntity.getSupplierName());
        checkVO.setDepartmentId(deliveryEntity.getDepartmentId());
        checkVO.setDepartmentName(deliveryEntity.getDepartmentName());
        checkVO.setLicensePlate(deliveryEntity.getLicensePlate());
        checkVO.setOrgId(deliveryEntity.getOrgId());
        checkVO.setOrgName(deliveryEntity.getOrgName());
        checkVO.setCheckType(CheckTypeEnum.发货验收.getCode());
        checkVO.setParentOrgId(deliveryEntity.getParentOrgId());
        checkVO.setParentOrgName(deliveryEntity.getParentOrgName());
        checkVO.setDeliveryCode(deliveryEntity.getBillCode());
        checkVO.setAutomaticWeigh(deliveryEntity.getAutomaticWeigh());
        checkVO.setDeliveryType(deliveryEntity.getDeliveryType());

        List<DeliveryDetailEntity> deliveryDetailList = deliveryEntity.getDeliveryDetailList();
        List<DeliveryDetailEntity> deliveryDetailEntityList = deliveryDetailList.stream().filter(s -> s.getDeliveryNum().compareTo(s.getCheckNum() == null ? BigDecimal.ZERO : s.getCheckNum()) == 1 )
                .collect(Collectors.toList());

        OrderEntity orderEntity = orderService.selectById(deliveryEntity.getOrderId());
        Map<Long, OrderDetailEntity> deliveryOrderMap = orderEntity.getOrderDetailList().stream().collect(Collectors.toMap(OrderDetailEntity::getId, Function.identity(), (k1, k2) -> k1));
        if (CollectionUtils.isNotEmpty(deliveryDetailEntityList)) {
            ArrayList<CheckDetailVO> checkDetailVOS = new ArrayList<>();
            for (DeliveryDetailEntity deliveryDetailEntity : deliveryDetailEntityList) {
                CheckDetailVO checkDetailVO = new CheckDetailVO();
                checkDetailVO.setCheckType(CheckTypeEnum.发货验收.getCode());
                checkDetailVO.setSourceId(deliveryEntity.getId());
                checkDetailVO.setSourceDetailId(deliveryDetailEntity.getId());

                OrderDetailEntity detailEntity = deliveryOrderMap.get(deliveryDetailEntity.getOrderDetailId());
                checkDetailVO.setMonthPlanId(detailEntity.getSourceId());
                checkDetailVO.setMonthPlanDetailId(detailEntity.getSourceDetailId());

                checkDetailVO.setMaterialId(deliveryDetailEntity.getMaterialId());
                checkDetailVO.setMaterialName(deliveryDetailEntity.getMaterialName());
                checkDetailVO.setMaterialTypeId(deliveryDetailEntity.getMaterialTypeId());
                checkDetailVO.setMaterialTypeName(deliveryDetailEntity.getMaterialTypeName());
                checkDetailVO.setMaterialCode(deliveryDetailEntity.getMaterialCode());
                checkDetailVO.setUnit(deliveryDetailEntity.getUnit());
                checkDetailVO.setUnitId(deliveryDetailEntity.getUnitId());
                checkDetailVO.setSpec(deliveryDetailEntity.getSpec());
                checkDetailVO.setDetailAutomaticWeigh(deliveryDetailEntity.getDetailAutomaticWeigh());
                checkDetailVO.setDeliverNum(deliveryDetailEntity.getDeliveryNum());
                checkDetailVO.setCheckNum(ComputeUtil.safeSub(deliveryDetailEntity.getDeliveryNum(), deliveryDetailEntity.getCheckNum()));
                checkDetailVOS.add(checkDetailVO);
            }
            checkVO.setCheckDetailList(checkDetailVOS);
        }
        return checkVO;
    }

    /**
     * type 0-关闭,1-新增和修改
     *
     * @param id
     * @return
     */
    @Override
    @Transactional
    public DeliveryVO closeDelivery(Long id) {
        DeliveryEntity deliveryEntity = super.selectById(id);
        deliveryEntity.setCloseFlag(1);
        super.updateById(deliveryEntity);
        //推送供方数据
        CommonResponse<String> ejcCloudSystemCode = proSupplierApi.getEjcCloudSystemCode();
        if (!ejcCloudSystemCode.isSuccess()) {
            throw new BusinessException("获取当前系统编码失败！");
        }
        Map<String, Object> map = new HashMap<>();
        map.put("sourceId", deliveryEntity.getSourceId());
        map.put("closeFlag", 1);
        map.put("systemId", ejcCloudSystemCode.getData());
        String dataInfo = JSONObject.toJSONString(map);
        Boolean updateSupplierStatus = updateSupplierStatus(deliveryEntity.getId(), dataInfo, PUSH_BILL_SERVER_URL, RequestMethod.POST,
                deliveryEntity.getSupplierId().toString(), OPERATE, BILL_TYPE_CODE);
        if (!updateSupplierStatus) {
            throw new BusinessException("单据推送失败！");
        }
        return BeanMapper.map(deliveryEntity, DeliveryVO.class);
    }

    @Override
    public Boolean updateSupplierStatus(Long billId, String dataInfo, String url, RequestMethod method, String supplierId, String operate, String billTypeCode) {
        //推送供方
        //对单据进行加锁
        Boolean locked = false;
        Boolean syncFlag = false;
        String key = billTypeCode + "::" + billId.toString();
        Jedis jedis = jedisPool.getResource();
        try {
            locked = RedisTool.tryLock(jedis, key, operate, 600);
            if (!locked) {
                releaseLock(jedis, false, key, operate);
                logger.error("单据{}推送失败，单据锁获取失败-{}！", billId, locked);
                return false;
            }
            CommonResponse<String> syncReqResp = systemDataPushService.exchangeDataWithEachLinkSystem(url, method, dataInfo, supplierId);
            if (syncReqResp.isSuccess()) {
                CommonResponse<String> billPushResp = JSONObject.parseObject(syncReqResp.getData(), CommonResponse.class);
                if (billPushResp.isSuccess()) {
                    syncFlag = true;
                } else {
                    logger.error("供方id-{}处理推送单据id-{}失败, {}", supplierId, billId, billPushResp.getMsg());
                }
            } else {
                logger.error("供方id-{}处理推送单据id-{}失败, {}", supplierId, billId, syncReqResp.getMsg());

            }
        } catch (Exception e) {
            logger.error("推送发货单单据id-{}给供方id-{} 异常，", billId, supplierId, e);
        } finally {
            //释放单据锁
            releaseLock(jedis, locked, key, operate);
        }
        return syncFlag;
    }

    @Override
    public DeliveryVO saveOrUpdates(DeliveryVO saveOrUpdateVO) {
        DeliveryEntity entity = BeanMapper.map(saveOrUpdateVO, DeliveryEntity.class);
        List<DeliveryDetailVO> materialDeliveryDetailList = saveOrUpdateVO.getMaterialDeliveryDetailList();
        List<DeliveryDetailEntity> deliveryDetailEntityList = BeanMapper.mapList(materialDeliveryDetailList, DeliveryDetailEntity.class);
        entity.setDeliveryDetailList(deliveryDetailEntityList);
        if (entity.getId() == null || entity.getId() == 0) {
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        entity.setCloseFlag(0);
        super.saveOrUpdate(entity, false);
        DeliveryVO vo = BeanMapper.map(entity, DeliveryVO.class);
        return vo;
    }

    @Override
    public DeliveryVO savePushThirdData(Long id) {
        DeliveryEntity entity = super.selectById(id);
        if (null != entity.getAutomaticWeigh() && 0 == entity.getAutomaticWeigh()) {
            //智能称重 才推送第三方
            /** 推送订单，运单-------------开始 */
            //1,获取订单经办人 送货地址     获取合同甲方
            DeliveryThirdVO thirdVO = BeanMapper.map(entity, DeliveryThirdVO.class);
            OrderEntity orderEntity = orderService.getById(entity.getOrderId());
            thirdVO.setEmployeeName(orderEntity.getEmployeeName() == null ? orderEntity.getCreateUserCode() : orderEntity.getEmployeeName());
            thirdVO.setOrderAddress(orderEntity.getOrderAddress());
            thirdVO.setDeliverType("CL");
            List<DeliveryDetailEntity> detailList = entity.getDeliveryDetailList();
            if (CollectionUtils.isNotEmpty(detailList)) {
                thirdVO.setDetailList(BeanMapper.mapList(detailList, DeliveryDetailThirdVO.class));
            }
            logger.info("消耗材推送第三方数据参数----：{}", JSONObject.toJSONString(thirdVO));
            CommonResponse<String> thirdRes = pushThirdDataApi.pushThirdData(thirdVO);
            if (thirdRes.isSuccess()) {
                logger.info("消耗材推送第三方数据----返回信息：{}", JSONObject.toJSONString(thirdRes.getMsg()));
                entity.setIsPushThird("sucPushed");
            } else {
                entity.setUnSucReason(thirdRes.getMsg());
            }
            super.updateById(entity);
        }
        /** 推送订单，运单-------------结束 */
        DeliveryVO vo = BeanMapper.map(entity, DeliveryVO.class);
        return vo;
    }


    public void releaseLock(Jedis jedis, boolean locked, String key, String OPERATE) {
        try {
            if (locked) {
                RedisTool.releaseLock(jedis, key, OPERATE);
            }
        } finally {
            if (null != jedis) {
                jedis.close();
            }
        }
    }


}

==> zjkj-wzxt-impl-3.0.0-20240814.071805-76-sources.jar: com/ejianc/wzxt/delivery/service/impl/DeliveryServiceImpl.java <==
package com.ejianc.wzxt.delivery.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.weigh.weighbill.api.IPushThirdDataApi;
import com.ejianc.business.weigh.weighbill.vo.DeliveryDetailThirdVO;
import com.ejianc.business.weigh.weighbill.vo.DeliveryThirdVO;
import com.ejianc.foundation.share.api.IProSupplierApi;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.cache.utils.RedisTool;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ComputeUtil;
import com.ejianc.framework.skeleton.dataPush.ISystemDataPushService;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import com.ejianc.wzxt.check.vo.CheckDetailVO;
import com.ejianc.wzxt.check.vo.CheckVO;
import com.ejianc.wzxt.delivery.bean.DeliveryDetailEntity;
import com.ejianc.wzxt.delivery.bean.DeliveryEntity;
import com.ejianc.wzxt.delivery.mapper.DeliveryMapper;
import com.ejianc.wzxt.delivery.service.IDeliveryService;
import com.ejianc.wzxt.delivery.vo.DeliveryDetailVO;
import com.ejianc.wzxt.delivery.vo.DeliveryVO;
import com.ejianc.wzxt.enums.CheckTypeEnum;
import com.ejianc.wzxt.order.bean.OrderDetailEntity;
import com.ejianc.wzxt.order.bean.OrderEntity;
import com.ejianc.wzxt.order.service.IOrderService;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestMethod;
import redis.clients.jedis.Jedis;
import redis.clients.jedis.JedisPool;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * 消耗材-发货单
 *
 * @author generator
 */
@Service("deliveryService")
public class DeliveryServiceImpl extends BaseServiceImpl<DeliveryMapper, DeliveryEntity> implements IDeliveryService {
    @Autowired
    private IDeliveryService deliveryService;
    private final Logger logger = LoggerFactory.getLogger(getClass());
    private final String PUSH_BILL_SERVER_URL = "/zjkj-supbusiness-web/openapi/delivery/saveMaterialDeliveryState";
    @Autowired
    private JedisPool jedisPool;
    @Autowired
    private IProSupplierApi proSupplierApi;
    @Autowired
    private IPushThirdDataApi pushThirdDataApi;
    @Autowired
    private IOrderService orderService;
    @Autowired
    private ISystemDataPushService systemDataPushService;
    private static final String BILL_CODE = "ZJKJ-DELIVERY-CODE";//此处需要根据实际修改
    private final String OPERATE = "ZJKJ_DELIVERY_SYNC";
    private static final String BILL_TYPE_CODE = "EJCBT202407000005";//此处需要根据实际修改
    @Autowired
    private IBillCodeApi billCodeApi;

    @Override
    public CheckVO queryDetailToCheck(Long id) {
        DeliveryEntity deliveryEntity = deliveryService.selectById(id);

        //处理组合验收数据返回
        CheckVO checkVO = new CheckVO();
        checkVO.setOrderId(deliveryEntity.getOrderId());
        checkVO.setDeliveryId(deliveryEntity.getId());
        checkVO.setDeliverName(deliveryEntity.getDeliverName());
        checkVO.setCheckState(0);
        checkVO.setContractId(deliveryEntity.getContractId());
        checkVO.setContractName(deliveryEntity.getContractName());
        checkVO.setContractCode(deliveryEntity.getContractCode());
        checkVO.setProjectCode(deliveryEntity.getProjectCode());
        checkVO.setProjectId(deliveryEntity.getProjectId());
        checkVO.setProjectName(deliveryEntity.getProjectName());
        checkVO.setSupplierId(deliveryEntity.getSupplierId());
        checkVO.setSupplierName(deliveryEntity.getSupplierName());
        checkVO.setDepartmentId(deliveryEntity.getDepartmentId());
        checkVO.setDepartmentName(deliveryEntity.getDepartmentName());
        checkVO.setLicensePlate(deliveryEntity.getLicensePlate());
        checkVO.setOrgId(deliveryEntity.getOrgId());
        checkVO.setOrgName(deliveryEntity.getOrgName());
        checkVO.setCheckType(CheckTypeEnum.发货验收.getCode());
        checkVO.setParentOrgId(deliveryEntity.getParentOrgId());
        checkVO.setParentOrgName(deliveryEntity.getParentOrgName());
        checkVO.setDeliveryCode(deliveryEntity.getBillCode());
        checkVO.setAutomaticWeigh(deliveryEntity.getAutomaticWeigh());
        checkVO.setDeliveryType(deliveryEntity.getDeliveryType());

        List<DeliveryDetailEntity> deliveryDetailList = deliveryEntity.getDeliveryDetailList();
        List<DeliveryDetailEntity> deliveryDetailEntityList = deliveryDetailList.stream().filter(s -> s.getDeliveryNum().compareTo(s.getCheckNum() == null ? BigDecimal.ZERO : s.getCheckNum()) == 1 )
                .collect(Collectors.toList());

        OrderEntity orderEntity = orderService.selectById(deliveryEntity.getOrderId());
        checkVO.setOrderCode(orderEntity.getBillCode());

        Map<Long, OrderDetailEntity> deliveryOrderMap = orderEntity.getOrderDetailList().stream().collect(Collectors.toMap(OrderDetailEntity::getId, Function.identity(), (k1, k2) -> k1));
        if (CollectionUtils.isNotEmpty(deliveryDetailEntityList)) {
            ArrayList<CheckDetailVO> checkDetailVOS = new ArrayList<>();
            for (DeliveryDetailEntity deliveryDetailEntity : deliveryDetailEntityList) {
                CheckDetailVO checkDetailVO = new CheckDetailVO();
                checkDetailVO.setCheckType(CheckTypeEnum.发货验收.getCode());
                checkDetailVO.setSourceId(deliveryEntity.getId());
                checkDetailVO.setSourceDetailId(deliveryDetailEntity.getId());

                OrderDetailEntity detailEntity = deliveryOrderMap.get(deliveryDetailEntity.getOrderDetailId());
                checkDetailVO.setMonthPlanId(detailEntity.getSourceId());
                checkDetailVO.setMonthPlanDetailId(detailEntity.getSourceDetailId());

                checkDetailVO.setMaterialId(deliveryDetailEntity.getMaterialId());
                checkDetailVO.setMaterialName(deliveryDetailEntity.getMaterialName());
                checkDetailVO.setMaterialTypeId(deliveryDetailEntity.getMaterialTypeId());
                checkDetailVO.setMaterialTypeName(deliveryDetailEntity.getMaterialTypeName());
                checkDetailVO.setMaterialCode(deliveryDetailEntity.getMaterialCode());
                checkDetailVO.setUnit(deliveryDetailEntity.getUnit());
                checkDetailVO.setUnitId(deliveryDetailEntity.getUnitId());
                checkDetailVO.setSpec(deliveryDetailEntity.getSpec());
                checkDetailVO.setDetailAutomaticWeigh(deliveryDetailEntity.getDetailAutomaticWeigh());
                checkDetailVO.setDeliverNum(deliveryDetailEntity.getDeliveryNum());
                checkDetailVO.setCheckNum(ComputeUtil.safeSub(deliveryDetailEntity.getDeliveryNum(), deliveryDetailEntity.getCheckNum()));
                checkDetailVOS.add(checkDetailVO);
            }
            checkVO.setCheckDetailList(checkDetailVOS);
        }
        return checkVO;
    }

    /**
     * type 0-关闭,1-新增和修改
     *
     * @param id
     * @return
     */
    @Override
    @Transactional
    public DeliveryVO closeDelivery(Long id) {
        DeliveryEntity deliveryEntity = super.selectById(id);
        deliveryEntity.setCloseFlag(1);
        super.updateById(deliveryEntity);
        //推送供方数据
        CommonResponse<String> ejcCloudSystemCode = proSupplierApi.getEjcCloudSystemCode();
        if (!ejcCloudSystemCode.isSuccess()) {
            throw new BusinessException("获取当前系统编码失败！");
        }
        Map<String, Object> map = new HashMap<>();
        map.put("sourceId", deliveryEntity.getSourceId());
        map.put("closeFlag", 1);
        map.put("systemId", ejcCloudSystemCode.getData());
        String dataInfo = JSONObject.toJSONString(map);
        Boolean updateSupplierStatus = updateSupplierStatus(deliveryEntity.getId(), dataInfo, PUSH_BILL_SERVER_URL, RequestMethod.POST,
                deliveryEntity.getSupplierId().toString(), OPERATE, BILL_TYPE_CODE);
        if (!updateSupplierStatus) {
            throw new BusinessException("单据推送失败！");
        }
        return BeanMapper.map(deliveryEntity, DeliveryVO.class);
    }

    @Override
    public Boolean updateSupplierStatus(Long billId, String dataInfo, String url, RequestMethod method, String supplierId, String operate, String billTypeCode) {
        //推送供方
        //对单据进行加锁
        Boolean locked = false;
        Boolean syncFlag = false;
        String key = billTypeCode + "::" + billId.toString();
        Jedis jedis = jedisPool.getResource();
        try {
            locked = RedisTool.tryLock(jedis, key, operate, 600);
            if (!locked) {
                releaseLock(jedis, false, key, operate);
                logger.error("单据{}推送失败，单据锁获取失败-{}！", billId, locked);
                return false;
            }
            CommonResponse<String> syncReqResp = systemDataPushService.exchangeDataWithEachLinkSystem(url, method, dataInfo, supplierId);
            if (syncReqResp.isSuccess()) {
                CommonResponse<String> billPushResp = JSONObject.parseObject(syncReqResp.getData(), CommonResponse.class);
                if (billPushResp.isSuccess()) {
                    syncFlag = true;
                } else {
                    logger.error("供方id-{}处理推送单据id-{}失败, {}", supplierId, billId, billPushResp.getMsg());
                }
            } else {
                logger.error("供方id-{}处理推送单据id-{}失败, {}", supplierId, billId, syncReqResp.getMsg());

            }
        } catch (Exception e) {
            logger.error("推送发货单单据id-{}给供方id-{} 异常，", billId, supplierId, e);
        } finally {
            //释放单据锁
            releaseLock(jedis, locked, key, operate);
        }
        return syncFlag;
    }

    @Override
    public DeliveryVO saveOrUpdates(DeliveryVO saveOrUpdateVO) {
        DeliveryEntity entity = BeanMapper.map(saveOrUpdateVO, DeliveryEntity.class);
        List<DeliveryDetailVO> materialDeliveryDetailList = saveOrUpdateVO.getMaterialDeliveryDetailList();
        List<DeliveryDetailEntity> deliveryDetailEntityList = BeanMapper.mapList(materialDeliveryDetailList, DeliveryDetailEntity.class);
        entity.setDeliveryDetailList(deliveryDetailEntityList);
        if (entity.getId() == null || entity.getId() == 0) {
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        entity.setCloseFlag(0);
        entity.setDeliveryType(2);
        super.saveOrUpdate(entity, false);
        DeliveryVO vo = BeanMapper.map(entity, DeliveryVO.class);
        return vo;
    }

    @Override
    public DeliveryVO savePushThirdData(Long id) {
        DeliveryEntity entity = super.selectById(id);
        if (null != entity.getAutomaticWeigh() && 0 == entity.getAutomaticWeigh()) {
            //智能称重 才推送第三方
            /** 推送订单，运单-------------开始 */
            //1,获取订单经办人 送货地址     获取合同甲方
            DeliveryThirdVO thirdVO = BeanMapper.map(entity, DeliveryThirdVO.class);
            OrderEntity orderEntity = orderService.getById(entity.getOrderId());
            thirdVO.setEmployeeName(orderEntity.getEmployeeName() == null ? orderEntity.getCreateUserCode() : orderEntity.getEmployeeName());
            thirdVO.setOrderAddress(orderEntity.getOrderAddress());
            thirdVO.setDeliverType("CL");
            List<DeliveryDetailEntity> detailList = entity.getDeliveryDetailList();
            if (CollectionUtils.isNotEmpty(detailList)) {
                thirdVO.setDetailList(BeanMapper.mapList(detailList, DeliveryDetailThirdVO.class));
            }
            logger.info("消耗材推送第三方数据参数----：{}", JSONObject.toJSONString(thirdVO));
            CommonResponse<String> thirdRes = pushThirdDataApi.pushThirdData(thirdVO);
            if (thirdRes.isSuccess()) {
                logger.info("消耗材推送第三方数据----返回信息：{}", JSONObject.toJSONString(thirdRes.getMsg()));
                entity.setIsPushThird("sucPushed");
            } else {
                entity.setUnSucReason(thirdRes.getMsg());
            }
            super.updateById(entity);
        }
        /** 推送订单，运单-------------结束 */
        DeliveryVO vo = BeanMapper.map(entity, DeliveryVO.class);
        return vo;
    }


    public void releaseLock(Jedis jedis, boolean locked, String key, String OPERATE) {
        try {
            if (locked) {
                RedisTool.releaseLock(jedis, key, OPERATE);
            }
        } finally {
            if (null != jedis) {
                jedis.close();
            }
        }
    }


}
